@@ -4,7 +4,7 @@ import os
 from modeldeploy_proxy_controller.common import logutils
 
 LOG_DIR = os.getenv("HOME", ".")
-LOG_BASENAME = "model-deployment-proxy-controller.log"
+LOG_BASENAME = "modeldeploy-proxy-controller.log"
 LOG_FILE = os.path.join(LOG_DIR, LOG_BASENAME)
 
 FMT_PREFIX = "%(asctime)s %(module)s:%(lineno)d [%(levelname)s] "
